==> kea-devel-docs-1.5.0-2.0-any.pkg.tar.zst: usr/share/doc/kea/devel/de/d13/namespaceisc_1_1hooks.js <==
var namespaceisc_1_1hooks =
[
    [ "CalloutHandle", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle.html", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle" ],
    [ "CalloutHandleAssociate", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate.html", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate" ],
    [ "CalloutManager", "d4/d67/classisc_1_1hooks_1_1CalloutManager.html", "d4/d67/classisc_1_1hooks_1_1CalloutManager" ],
    [ "DuplicateHook", "db/de0/classisc_1_1hooks_1_1DuplicateHook.html", "db/de0/classisc_1_1hooks_1_1DuplicateHook" ],
    [ "HooksConfig", "d0/d40/classisc_1_1hooks_1_1HooksConfig.html", "d0/d40/classisc_1_1hooks_1_1HooksConfig" ],
    [ "HooksLibrariesParser", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser.html", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser" ],
    [ "HooksManager", "d4/d88/classisc_1_1hooks_1_1HooksManager.html", null ],
    [ "InvalidHooksLibraries", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries.html", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries" ],
    [ "LibraryHandle", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle.html", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle" ],
    [ "LibraryManager", "d4/d98/classisc_1_1hooks_1_1LibraryManager.html", "d4/d98/classisc_1_1hooks_1_1LibraryManager" ],
    [ "LibraryManagerCollection", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection.html", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection" ],
    [ "LoadLibrariesNotCalled", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled" ],
    [ "NoCalloutManager", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager.html", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager" ],
    [ "NoSuchArgument", "db/dee/classisc_1_1hooks_1_1NoSuchArgument.html", "db/dee/classisc_1_1hooks_1_1NoSuchArgument" ],
    [ "NoSuchCalloutContext", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext.html", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext" ],
    [ "NoSuchHook", "d4/d70/classisc_1_1hooks_1_1NoSuchHook.html", "d4/d70/classisc_1_1hooks_1_1NoSuchHook" ],
    [ "NoSuchLibrary", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary.html", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary" ],
    [ "ParkingLot", "dd/db4/classisc_1_1hooks_1_1ParkingLot.html", "dd/db4/classisc_1_1hooks_1_1ParkingLot" ],
    [ "ParkingLotHandle", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle.html", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle" ],
    [ "ParkingLots", "d3/dc8/classisc_1_1hooks_1_1ParkingLots.html", "d3/dc8/classisc_1_1hooks_1_1ParkingLots" ],
    [ "PointerConverter", "da/d42/classisc_1_1hooks_1_1PointerConverter.html", "da/d42/classisc_1_1hooks_1_1PointerConverter" ],
    [ "ScopedCalloutHandleState", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState.html", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState" ],
    [ "ServerHooks", "dc/d4b/classisc_1_1hooks_1_1ServerHooks.html", "dc/d4b/classisc_1_1hooks_1_1ServerHooks" ]
];

==> kea-devel-docs-1.5.0-2.1-any.pkg.tar.zst: usr/share/doc/kea/devel/de/d13/namespaceisc_1_1hooks.js <==
var namespaceisc_1_1hooks =
[
    [ "CalloutHandle", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle.html", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle" ],
    [ "CalloutHandleAssociate", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate.html", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate" ],
    [ "CalloutManager", "d4/d67/classisc_1_1hooks_1_1CalloutManager.html", "d4/d67/classisc_1_1hooks_1_1CalloutManager" ],
    [ "DuplicateHook", "db/de0/classisc_1_1hooks_1_1DuplicateHook.html", "db/de0/classisc_1_1hooks_1_1DuplicateHook" ],
    [ "HooksConfig", "d0/d40/classisc_1_1hooks_1_1HooksConfig.html", "d0/d40/classisc_1_1hooks_1_1HooksConfig" ],
    [ "HooksLibrariesParser", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser.html", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser" ],
    [ "HooksManager", "d4/d88/classisc_1_1hooks_1_1HooksManager.html", null ],
    [ "InvalidHooksLibraries", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries.html", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries" ],
    [ "LibraryHandle", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle.html", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle" ],
    [ "LibraryManager", "d4/d98/classisc_1_1hooks_1_1LibraryManager.html", "d4/d98/classisc_1_1hooks_1_1LibraryManager" ],
    [ "LibraryManagerCollection", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection.html", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection" ],
    [ "LoadLibrariesNotCalled", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled" ],
    [ "NoCalloutManager", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager.html", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager" ],
    [ "NoSuchArgument", "db/dee/classisc_1_1hooks_1_1NoSuchArgument.html", "db/dee/classisc_1_1hooks_1_1NoSuchArgument" ],
    [ "NoSuchCalloutContext", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext.html", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext" ],
    [ "NoSuchHook", "d4/d70/classisc_1_1hooks_1_1NoSuchHook.html", "d4/d70/classisc_1_1hooks_1_1NoSuchHook" ],
    [ "NoSuchLibrary", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary.html", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary" ],
    [ "ParkingLot", "dd/db4/classisc_1_1hooks_1_1ParkingLot.html", "dd/db4/classisc_1_1hooks_1_1ParkingLot" ],
    [ "ParkingLotHandle", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle.html", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle" ],
    [ "ParkingLots", "d3/dc8/classisc_1_1hooks_1_1ParkingLots.html", "d3/dc8/classisc_1_1hooks_1_1ParkingLots" ],
    [ "PointerConverter", "da/d42/classisc_1_1hooks_1_1PointerConverter.html", "da/d42/classisc_1_1hooks_1_1PointerConverter" ],
    [ "ScopedCalloutHandleState", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState.html", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState" ],
    [ "ServerHooks", "dc/d4b/classisc_1_1hooks_1_1ServerHooks.html", "dc/d4b/classisc_1_1hooks_1_1ServerHooks" ],
    [ "CalloutHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a8daec5c473b714625a7afe8caaa7b0cb", null ],
    [ "CalloutPtr", "de/d13/namespaceisc_1_1hooks.html#a25e0b3cae1cc1b876313797a010e2af5", null ],
    [ "HookLibInfo", "de/d13/namespaceisc_1_1hooks.html#a001ff7519899ad231220986dd13500fd", null ],
    [ "HookLibsCollection", "de/d13/namespaceisc_1_1hooks.html#a773818c8b5dc3e49ce9705324256a1e1", null ],
    [ "HookLibsCollectionPtr", "de/d13/namespaceisc_1_1hooks.html#a55a63a86b249c1ed2596d6ddadafbc78", null ],
    [ "ParkingLotHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a2363ee6ae0a46a86c9b59a34c199e08b", null ],
    [ "ParkingLotPtr", "de/d13/namespaceisc_1_1hooks.html#af7bee158c4d7a5963cf7a9794bd1d792", null ],
    [ "ParkingLotsPtr", "de/d13/namespaceisc_1_1hooks.html#a20721fe6188da398c74e0881e79c69c3", null ],
    [ "ServerHooksPtr", "de/d13/namespaceisc_1_1hooks.html#a37d12f02f9496f7d4a0f0da7b328541c", null ],
    [ "extractNames", "de/d13/namespaceisc_1_1hooks.html#a1ab505936a27f640b04fc395c8af14d1", null ],
    [ "hooksStaticLinkInit", "de/d13/namespaceisc_1_1hooks.html#a05bf2d7e4b0cd04996efc2bf79ac8f32", null ],
    [ "callouts_logger", "de/d13/namespaceisc_1_1hooks.html#acbbb2087d9d36ce66da865cf425e6c72", null ],
    [ "HOOKS_DBG_CALLS", "de/d13/namespaceisc_1_1hooks.html#aaa77c5c31926f41257d889e8db802bc2", null ],
    [ "HOOKS_DBG_EXTENDED_CALLS", "de/d13/namespaceisc_1_1hooks.html#a2f8600b642c8eb467c5bd94ea9760f33", null ],
    [ "HOOKS_DBG_TRACE", "de/d13/namespaceisc_1_1hooks.html#aba65face2cfe789f3b2aacb225e39aa2", null ],
    [ "hooks_logger", "de/d13/namespaceisc_1_1hooks.html#a71f7ced36e8ea37b60cc7cb16eb9bc9f", null ]
];
